@@ -5,10 +5,10 @@ print.haplin.ready <- function( x, ... ){
 		with following dimensions:
 	" )
 	if( !is.null( x$cov.data ) ){
-		cat( "  - number of covariate variables = ", ncol( x$cov.data ), "," )
+		cat( "  - number of covariate variables = ", ncol( x$cov.data ), ",\n" )
 	} else {
-		cat( "  - no covariate variables," )
+		cat( "  - no covariate variables,\n" )
 	}
-	cat( "  - number of markers = ", length( x$aux$marker.names ), "," )
-	cat( "  - number of individuals/families = ", nrow( x$gen.data[[ 1 ]] ) )
+	cat( "  - number of markers = ", length( x$aux$marker.names ), ",\n" )
+	cat( "  - number of individuals/families = ", nrow( x$gen.data[[ 1 ]] ), "\n" )
 }
